==> de_core-0.0.1.tar.gz: de_core-0.0.1/setup.py <==
""" setup """
import pprint
import setuptools


if __name__ == "__main__":
    setup_kwargs = dict(
        name='de_core',              # pip install name (not the import package name)
        version='0.0.1',
        author="Andi Ecker",
        author_email="aecker2@gmail.com",
        description="de_core portion of python application environment namespace package",
        # long_description=ae.core.file_content("README.md"),
        # long_description_content_type="text/markdown",
        url="https://gitlab.com/degroup/de_core",
        # don't needed for native/implicit namespace packages: namespace_packages=[namespace_name],
        # packages=setuptools.find_packages(),
        packages=setuptools.find_namespace_packages(include=['de']),  # find namespace portions
        python_requires=">=3.6",
        # install_requires=install_require,
        # extras_require={
        #     'docs': docs_require,
        #     'tests': tests_require,
        #     'dev': docs_require + tests_require,
        # },
        classifiers=[
            "Development Status :: 1 - Planning",
            "Natural Language :: English",
            "Operating System :: OS Independent",
            "Programming Language :: Python",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.6",
            "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
            "Operating System :: OS Independent",
            "Topic :: Software Development :: Libraries",
        ],
        keywords=[
            'productivity',
            'environment',
            'configuration',
            'development',
        ]
    )
    print("#  EXECUTING SETUPTOOLS SETUP #################################")
    print(pprint.pformat(setup_kwargs, indent=3, width=75, compact=True))
    setuptools.setup(**setup_kwargs)
    print("#  FINISHED SETUPTOOLS SETUP  #################################")

==> de_core-0.0.2.tar.gz: de_core-0.0.2/setup.py <==
""" setup """
import pprint
import setuptools


if __name__ == "__main__":
    setup_kwargs = dict(
        name='de_core',              # pip install name (not the import package name)
        version='0.0.2',
        author="Andi Ecker",
        author_email="aecker2@gmail.com",
        description="de_core portion of python development environment namespace package",
        # long_description=ae.core.file_content("README.md"),
        # long_description=ae.core.file_content("README.md"),
        # long_description_content_type="text/markdown",
        url="https://gitlab.com/degroup/de_core",
        # don't needed for native/implicit namespace packages: namespace_packages=[namespace_name],
        # packages=setuptools.find_packages(),
        packages=setuptools.find_namespace_packages(include=['de']),  # find namespace portions
        python_requires=">=3.6",
        # install_requires=install_require,
        # extras_require={
        #     'docs': docs_require,
        #     'tests': tests_require,
        #     'dev': docs_require + tests_require,
        # },
        classifiers=[
            "Development Status :: 1 - Planning",
            "Natural Language :: English",
            "Operating System :: OS Independent",
            "Programming Language :: Python",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.6",
            "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
            "Operating System :: OS Independent",
            "Topic :: Software Development :: Libraries",
        ],
        keywords=[
            'productivity',
            'environment',
            'configuration',
            'development',
        ]
    )
    print("#  EXECUTING SETUPTOOLS SETUP #################################")
    print(pprint.pformat(setup_kwargs, indent=3, width=75, compact=True))
    setuptools.setup(**setup_kwargs)
    print("#  FINISHED SETUPTOOLS SETUP  #################################")
